@@ -2,6 +2,7 @@ from fractions import Fraction
 from typing import TypeVar, cast, Optional, Union
 from ..pitch import EquaveCyclicCollection, AddressedPitchCollection, IntervalType, _addressed_collection_cache, IntervalList, Pitch
 import numpy as np
+from ...topos.graphs import Graph
 
 PC = TypeVar('PC', bound='Chord')
 
@@ -33,7 +34,7 @@ class AddressedChord(AddressedPitchCollection):
         
         lowest_interval = self._collection.degrees[0]
         
-        if self._collection.interval_type == float:
+        if self._collection.interval_type == float or (hasattr(self._collection, '_interval_type_mode') and self._collection._interval_type_mode == "cents"):
             freq_ratio = 2**((interval - lowest_interval)/1200)
             return Pitch.from_freq(self._reference_pitch.freq * freq_ratio)
         else:
@@ -70,14 +71,32 @@ class Chord(EquaveCyclicCollection[IntervalType]):
     """
     
     def __init__(self, degrees: IntervalList = ["1/1", "5/4", "3/2"], 
-                 equave: Optional[Union[float, Fraction, int, str]] = "2/1"):
-        super().__init__(degrees, equave)
+                 equave: Optional[Union[float, Fraction, int, str]] = "2/1",
+                 interval_type: str = "ratios"):
+        super().__init__(degrees, equave, interval_type)
+        self._graph = self._generate_graph()
+    
+    def _generate_graph(self):
+        """Generate a complete graph with chord degrees as nodes."""
+        n_nodes = len(self._degrees)
+        if n_nodes == 0:
+            return Graph()
+        
+        G = Graph.complete_graph(n_nodes)
+        for i, degree in enumerate(self._degrees):
+            G.set_node_data(i, degree=degree, index=i)
+        return G
+    
+    @property
+    def graph(self):
+        """A complete graph with chord degrees as nodes."""
+        return self._graph
     
     def __invert__(self: PC) -> PC:
         if len(self._degrees) <= 1:
-            return Chord(self._degrees.copy(), self._equave)
+            return Chord(self._degrees.copy(), self._equave, self._interval_type_mode)
         
-        if self.interval_type == float:
+        if self._interval_type_mode == "cents":
             new_degrees = [self._degrees[0]]
             for i in range(len(self._degrees) - 1, 0, -1):
                 interval_difference = self._degrees[i] - self._degrees[i-1]
@@ -88,7 +107,7 @@ class Chord(EquaveCyclicCollection[IntervalType]):
                 interval_ratio = self._degrees[i] / self._degrees[i-1]
                 new_degrees.append(new_degrees[-1] * interval_ratio)
         
-        return Chord(new_degrees, self._equave)
+        return Chord(new_degrees, self._equave, self._interval_type_mode)
     
     def __neg__(self: PC) -> PC:
         return self.__invert__()
