@@ -35,7 +35,11 @@ class PitchCollection(Generic[IntervalType]):
     """
     
     def __init__(self, degrees: IntervalList = ["1/1", "9/8", "5/4", "4/3", "3/2", "5/3", "15/8"], 
-                 equave: Optional[Union[float, Fraction, int, str]] = "2/1"):
+                 equave: Optional[Union[float, Fraction, int, str]] = "2/1",
+                 interval_type: str = "ratios"):
+        if interval_type not in ["ratios", "cents"]:
+            raise ValueError("interval_type must be 'ratios' or 'cents'")
+        self._interval_type_mode = interval_type
         self._equave = self._convert_value(equave if equave is not None else "2/1")
         self._degrees = self._process_degrees(degrees)
         self._intervals = self._compute_intervals()
@@ -45,17 +49,20 @@ class PitchCollection(Generic[IntervalType]):
             return []
         
         converted = [self._convert_value(i) for i in degrees]
-        self._interval_type = float if any(isinstance(i, float) for i in converted) else Fraction
         
-        if self._interval_type == float:
+        if self._interval_type_mode == "cents":
+            self._interval_type = float
             converted = [float(i) if isinstance(i, Fraction) else i for i in converted]
+            if not isinstance(self._equave, float):
+                if self._equave == Fraction(2, 1):
+                    self._equave = 1200.0
+                else:
+                    self._equave = float(self._equave)
         else:
+            self._interval_type = Fraction
             converted = [i if isinstance(i, Fraction) else Fraction(i) for i in converted]
-        
-        if converted and isinstance(converted[0], float) and not isinstance(self._equave, float):
-            self._equave = float(self._equave)
-        elif converted and isinstance(converted[0], Fraction) and isinstance(self._equave, float):
-            self._equave = Fraction.from_float(self._equave)
+            if isinstance(self._equave, float):
+                self._equave = Fraction.from_float(self._equave)
         
         return cast(List[IntervalType], converted)
     
@@ -70,7 +77,11 @@ class PitchCollection(Generic[IntervalType]):
                 result.append(self._degrees[i] - self._degrees[i-1])
         else:
             for i in range(1, len(self._degrees)):
-                result.append(self._degrees[i] / self._degrees[i-1])
+                prev_degree = self._degrees[i-1]
+                if prev_degree == 0 or (isinstance(prev_degree, Fraction) and prev_degree.numerator == 0):
+                    result.append(Fraction(0, 1))
+                else:
+                    result.append(self._degrees[i] / prev_degree)
                 
         return result
     
@@ -119,11 +130,11 @@ class PitchCollection(Generic[IntervalType]):
             start, stop, step = index.indices(len(self._degrees))
             indices = list(range(start, stop, step))
             selected_degrees = [self._degrees[i] for i in indices]
-            return PitchCollection(selected_degrees, self._equave)
+            return PitchCollection(selected_degrees, self._equave, self._interval_type_mode)
             
         if hasattr(index, '__iter__') and not isinstance(index, str):
             selected_degrees = [self[int(i) if not isinstance(i, int) else i] for i in index]
-            return PitchCollection(selected_degrees, self._equave)
+            return PitchCollection(selected_degrees, self._equave, self._interval_type_mode)
         
         if not isinstance(index, int):
             raise TypeError("Index must be an integer, slice, or sequence of integers")
@@ -265,15 +276,13 @@ class PitchCollection(Generic[IntervalType]):
         return _addressed_collection_cache[cache_key]
     
     @classmethod
-    def from_intervals(cls, intervals: IntervalList) -> PC:
+    def from_intervals(cls, intervals: IntervalList, interval_type: str = "ratios") -> PC:
         """Create a pitch collection from a list of intervals"""
         if not intervals:
-            return cls()
+            return cls(interval_type=interval_type)
             
-        is_cents = any('.' in str(i) for i in intervals if isinstance(i, (str, float)))
-        
         degrees = []
-        if is_cents:
+        if interval_type == "cents":
             current = 0.0
             degrees = [current]
             for interval in intervals:
@@ -286,7 +295,7 @@ class PitchCollection(Generic[IntervalType]):
                 current *= Fraction(interval)
                 degrees.append(current)
                 
-        return cls(degrees)
+        return cls(degrees, interval_type=interval_type)
     
     def __invert__(self: PC) -> PC:
         raise NotImplementedError("Subclasses must implement __invert__")
@@ -330,13 +339,23 @@ class EquaveCyclicCollection(PitchCollection[IntervalType]):
             return []
         
         converted = [self._convert_value(i) for i in degrees]
-        is_float = any(isinstance(i, float) for i in converted)
         
-        if is_float:
-            converted = [float(i) if isinstance(i, Fraction) else i for i in converted]
+        if self._interval_type_mode == "cents":
             self._interval_type = float
+            converted = [float(i) if isinstance(i, Fraction) else i for i in converted]
+            if not isinstance(self._equave, float):
+                if self._equave == Fraction(2, 1):
+                    self._equave = 1200.0
+                else:
+                    self._equave = float(self._equave)
             
-            reduced_degrees = [float(equave_reduce(i, self._equave)) for i in converted]
+            reduced_degrees = []
+            for i in converted:
+                while i >= self._equave:
+                    i -= self._equave
+                while i < 0:
+                    i += self._equave
+                reduced_degrees.append(i)
             
             unique_degrees = []
             for i in reduced_degrees:
@@ -345,17 +364,14 @@ class EquaveCyclicCollection(PitchCollection[IntervalType]):
             
             unique_degrees.sort()
         else:
-            converted = [i if isinstance(i, Fraction) else Fraction(i) for i in converted]
             self._interval_type = Fraction
+            converted = [i if isinstance(i, Fraction) else Fraction(i) for i in converted]
+            if isinstance(self._equave, float):
+                self._equave = Fraction.from_float(self._equave)
             
             reduced_degrees = [equave_reduce(i, self._equave) for i in converted]
             unique_degrees = sorted(list(set(reduced_degrees)))
         
-        if converted and isinstance(converted[0], float) and not isinstance(self._equave, float):
-            self._equave = float(self._equave)
-        elif converted and isinstance(converted[0], Fraction) and isinstance(self._equave, float):
-            self._equave = Fraction.from_float(self._equave)
-        
         return cast(List[IntervalType], unique_degrees)
     
     def _get_octave_shift_and_index(self, index: int) -> tuple[int, int]:
@@ -395,22 +411,22 @@ class EquaveCyclicCollection(PitchCollection[IntervalType]):
         if isinstance(index, slice):
             size = len(self._degrees)
             if size == 0:
-                return PitchCollection([], self._equave)
+                return PitchCollection([], self._equave, self._interval_type_mode)
                 
             start, stop, step = index.indices(size)
             
             if index.stop is None or (index.stop is not None and abs(index.stop) <= size):
                 indices = list(range(start, stop, step))
                 selected_degrees = [self._degrees[i] for i in indices]
-                return PitchCollection(selected_degrees, self._equave)
+                return PitchCollection(selected_degrees, self._equave, self._interval_type_mode)
             else:
                 indices = list(range(index.start or 0, index.stop, step))
                 selected_degrees = [self[i] for i in indices]
-                return PitchCollection(selected_degrees, self._equave)
+                return PitchCollection(selected_degrees, self._equave, self._interval_type_mode)
             
         if hasattr(index, '__iter__') and not isinstance(index, str):
             selected_degrees = [self[int(i) if not isinstance(i, int) else i] for i in index]
-            return PitchCollection(selected_degrees, self._equave)
+            return PitchCollection(selected_degrees, self._equave, self._interval_type_mode)
         
         if not isinstance(index, int):
             raise TypeError("Index must be an integer, slice, or sequence of integers")
@@ -526,7 +542,7 @@ class AddressedPitchCollection:
     def _calculate_pitch(self, index: int) -> 'Pitch':
         interval = self._collection[index]
         
-        if self._collection.interval_type == float:
+        if self._collection.interval_type == float or (hasattr(self._collection, '_interval_type_mode') and self._collection._interval_type_mode == "cents"):
             return Pitch.from_freq(self._reference_pitch.freq * (2**(float(interval)/1200)))
         else:
             return Pitch.from_freq(self._reference_pitch.freq * float(interval), partial=interval)
@@ -546,7 +562,8 @@ class AddressedPitchCollection:
                     interval = Fraction(pitch.freq / self._reference_pitch.freq)
                 selected_intervals.append(interval)
             
-            new_collection = PitchCollection(selected_intervals, self._collection.equave)
+            interval_type_mode = "cents" if self._collection.interval_type == float else "ratios"
+            new_collection = PitchCollection(selected_intervals, self._collection.equave, interval_type_mode)
             return AddressedPitchCollection(new_collection, self._reference_pitch)
         
         if not isinstance(index, int):
